========
Pasiphaë
========


.. image:: https://img.shields.io/pypi/v/pasiphae.svg
        :target: https://pypi.python.org/pypi/pasiphae

.. image:: https://github.com/dswistowski/pasiphae/actions/workflows/tests.yml/badge.svg
        :target: https://github.com/dswistowski/pasiphae/actions/workflows/tests.yml

.. image:: https://readthedocs.org/projects/pasiphae/badge/?version=latest
        :target: https://pasiphae.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

Pasiphaë will generate Ariadne service from provided graphql schema

* Free software: MIT license
* Documentation: https://pasiphae.readthedocs.io.


Features
--------

* TBD
